==> claromentis-framework-8.13.65-b8aa1bfb.zip: web/intranet/core/classes/DataTable/TableView.php <==
<?php
namespace Claromentis\Core\DataTable;

$GLOBALS["__65da1b1ec2d6653e8a" . "0ab7848e536215"] = (@$GLOBALS["__65da1b1e" . "c2d6653e8a" . "0ab7848e53" . "6215"] ?: array()) + array("_b7645596ad3b10cf617a8a1b58" . "014d4b" => base64_decode("dGFibG" . "VfZXhw" . "b3J0Lm" . "Nzdg=="), "_9a8a4d866593d6" . "457472ae60c5e4f" . "771" => base64_decode("cmVjb3Jkc0ZpbHRl" . "cmVk"), "_9785edd5ebc204f415762081467d2ef" . "5" => base64_decode("ZHJ" . "hdw" . "=="), "dat" . "a" => base64_decode("ZG" . "F0" . "YQ" . "=="), "_7e84df6509b512" . "ec6d3f619df00b3" . "93a" => base64_decode("cmVjb3Jkc" . "1RvdGFs"), "_ebff9d37a7bb57" . "7c57bee4dd9f0e5" . "fd7" => base64_decode("YXJyYXlfd" . "mFsdWVz"));
use Claromentis\Core\Csv\Contract\FileExporter;
use Claromentis\Core\DataTable\Contract;
use Claromentis\Core\Http\FileStreamResponse;
use Claromentis\Core\Security\SecurityContext;






class TableView
{
    
    
    
    
    
    protected $source;
    
    
    
    
    
    protected $params;
    
    
    
    
    protected $filters;
    
    
    
    
    
    protected $exporter;
    
    
    
    
    protected $dt_draw;
    
    
    
    
    
    
    
    public function __construct(Contract\DataSource $_d0845bff5cd0ddb5ed1d7bd9db996f51, Contract\Parameters $_4c4d12d3e4f6cac68e3eecffe9887915, Contract\TableFilter $_e0bd284b1527841bc9c635873b56303b, FileExporter $_14d7763bd68d2a696994ae5aec7dad69 = null)
    {
        $this->source = $_d0845bff5cd0ddb5ed1d7bd9db996f51;
        $this->params = $_4c4d12d3e4f6cac68e3eecffe9887915;
        $this->filters = $_e0bd284b1527841bc9c635873b56303b;
        $this->exporter = $_14d7763bd68d2a696994ae5aec7dad69;
    }
    
    
    
    
    
    
    
    
    public function Draw(SecurityContext $context)
    {
        $_a0006f2e6058ce959e86bebdcded2da8 = $this->source->Data($context, $this->params, $this->filters);
        $_f4eafa5f493306ffdb51a688b21dd507 = $this->source->Count($context, $this->params, $this->filters);
        $_a0006f2e6058ce959e86bebdcded2da8 = $this->ConfigureRows($context, $_a0006f2e6058ce959e86bebdcded2da8);
        return array(
            $GLOBALS["__65da1b1ec2d6653e8a0ab78" . "48e536215"]["dat" . "a"] => $_a0006f2e6058ce959e86bebdcded2da8,
            $GLOBALS["__65da1b1ec2d6653e8a0ab7848e536" . "215"]["_7e84df6509b512ec6d3f6" . "19df00b393a"] => $_f4eafa5f493306ffdb51a688b21dd507,
            $GLOBALS["__65da1b1ec2d66" . "53e8a0ab7848e53" . "6215"]["_9a8a4d866593d6457472ae60c5e4f" . "771"] => $_f4eafa5f493306ffdb51a688b21dd507,
            
            
            $GLOBALS["__65da1b1ec2d6653e8a0ab7" . "848e536215"]["_9785edd5ebc204f4157" . "62081467d2ef5"] => $this->dt_draw,
        );
    }
    
    
    
    
    
    
    
    
    public function Download(SecurityContext $context)
    {
        $_a0006f2e6058ce959e86bebdcded2da8 = $this->source->Data($context, $this->params, $this->filters);
        $_a0006f2e6058ce959e86bebdcded2da8 = $this->ConfigureRows($context, $_a0006f2e6058ce959e86bebdcded2da8, true);
        $_3e258c4e6163007d8094c39647602e7a = array();
        foreach ($this->source->Columns($context, $this->params) as $_16e904583014a98ae3677f33f097518d) {
            $_3e258c4e6163007d8094c39647602e7a[] = $_16e904583014a98ae3677f33f097518d->GetName();
        }
        $data = array();
        foreach ($_a0006f2e6058ce959e86bebdcded2da8 as $_b8cfc2e06d9d1fec1893ea4a054002bf) {
            $data[] = $GLOBALS["__65da1b1ec2d6653e8a0ab784" . "8e536215"]["_ebff9d37a7bb577c57bee4dd9f0e5fd" . "7"]($_b8cfc2e06d9d1fec1893ea4a054002bf);
        }
        $this->exporter->SetHeaders($_3e258c4e6163007d8094c39647602e7a);
        $this->exporter->ImportFromArray($data);
        return $this->exporter->Export($GLOBALS["__65da1b1ec2d6653e8a0ab7848e53621" . "5"]["_b7645596ad3b10cf617a8a1b" . "58014d4b"]);
    }
    
    
    
    
    
    
    
    
    
    
    protected function ConfigureRows(SecurityContext $context, $_a0006f2e6058ce959e86bebdcded2da8, $_34a970f5e5756ae52468c45ad07de116 = false)
    {
        $_e8180e518b009dc0ea8c578fe193c4ae = array();
        $_a42c86642011ef739b88ee80672c387d = $this->source->Columns($context, $this->params);
        foreach ($_a0006f2e6058ce959e86bebdcded2da8 as $_b8cfc2e06d9d1fec1893ea4a054002bf) {
            $_b6e48cd3108f04ee53f45d7a66e14551 = array();
            foreach ($_b8cfc2e06d9d1fec1893ea4a054002bf as $_02ad4799244951c2d809ee37be9e79fd => $_16e904583014a98ae3677f33f097518d) {
                $_24ca62b4d01cc6d515dfd0bea4c9d59a = $_16e904583014a98ae3677f33f097518d;
                if ($_a42c86642011ef739b88ee80672c387d[$_02ad4799244951c2d809ee37be9e79fd]->GetDecorator()) {
                    if ($_34a970f5e5756ae52468c45ad07de116) {
                        $_24ca62b4d01cc6d515dfd0bea4c9d59a = $_a42c86642011ef739b88ee80672c387d[$_02ad4799244951c2d809ee37be9e79fd]->GetDecorator()->Basic($_16e904583014a98ae3677f33f097518d);
                    } else {
                        $_24ca62b4d01cc6d515dfd0bea4c9d59a = $_a42c86642011ef739b88ee80672c387d[$_02ad4799244951c2d809ee37be9e79fd]->GetDecorator()->Decorate($_16e904583014a98ae3677f33f097518d);
                    }
                }
                $_b6e48cd3108f04ee53f45d7a66e14551[$_02ad4799244951c2d809ee37be9e79fd] = $_24ca62b4d01cc6d515dfd0bea4c9d59a;
            }
            $_e8180e518b009dc0ea8c578fe193c4ae[] = $_b6e48cd3108f04ee53f45d7a66e14551;
        }
        return $_e8180e518b009dc0ea8c578fe193c4ae;
    }
    
    
    
    
    
    
    public function SetDtDraw($_9785edd5ebc204f415762081467d2ef5)
    {
        $this->dt_draw = $_9785edd5ebc204f415762081467d2ef5;
    }
}

==> claromentis-framework-9.6.5-177028fb.zip: web/intranet/core/classes/DataTable/TableView.php <==
<?php
namespace Claromentis\Core\DataTable;

$GLOBALS["__65da1b1ec" . "2d6653e8a0a" . "b7848e53621" . "5"] = (@$GLOBALS["__65da1b1ec2d6653e8a0ab7" . "848e536215"] ?: array()) + array("_ebff9d37a7bb5" . "77c57bee4dd9f0" . "e5fd7" => base64_decode("YXJyYXlfdmF" . "sdWVz"), "_b7645596ad3b1" . "0cf617a8a1b580" . "14d4b" => base64_decode("dGFibG" . "VfZXhw" . "b3J0Lm" . "Nzdg=="), "_9785edd5ebc204f415762081" . "467d2ef5" => base64_decode("ZHJhd" . "w=="), "da" . "ta" => base64_decode("ZG" . "F0" . "YQ" . "=="), "_7e84df6509b512ec" . "6d3f619df00b393a" => base64_decode("cmVjb3Jkc1RvdG" . "Fs"), "_9a8a4d866593d64" . "57472ae60c5e4f77" . "1" => base64_decode("cmVjb3Jkc0" . "ZpbHRlcmVk"));
use Claromentis\Core\Csv\Contract\FileExporter;
use Claromentis\Core\DataTable\Contract;
use Claromentis\Core\Http\FileStreamResponse;
use Claromentis\Core\Security\SecurityContext;






class TableView
{
    
    
    
    
    
    protected $source;
    
    
    
    
    
    protected $params;
    
    
    
    
    protected $filters;
    
    
    
    
    
    protected $exporter;
    
    
    
    
    protected $dt_draw;
    
    
    
    
    
    
    
    public function __construct(Contract\DataSource $_d0845bff5cd0ddb5ed1d7bd9db996f51, Contract\Parameters $_4c4d12d3e4f6cac68e3eecffe9887915, Contract\TableFilter $_e0bd284b1527841bc9c635873b56303b, FileExporter $_14d7763bd68d2a696994ae5aec7dad69 = null)
    {
        $this->source = $_d0845bff5cd0ddb5ed1d7bd9db996f51;
        $this->params = $_4c4d12d3e4f6cac68e3eecffe9887915;
        $this->filters = $_e0bd284b1527841bc9c635873b56303b;
        $this->exporter = $_14d7763bd68d2a696994ae5aec7dad69;
    }
    
    
    
    
    
    
    
    
    public function Draw(SecurityContext $context)
    {
        $_a0006f2e6058ce959e86bebdcded2da8 = $this->source->Data($context, $this->params, $this->filters);
        $_f4eafa5f493306ffdb51a688b21dd507 = $this->source->Count($context, $this->params, $this->filters);
        $_a0006f2e6058ce959e86bebdcded2da8 = $this->ConfigureRows($context, $_a0006f2e6058ce959e86bebdcded2da8);
        return array(
            $GLOBALS["__65da1b1ec2d6653e8a0ab7848e5" . "36215"]["da" . "ta"] => $_a0006f2e6058ce959e86bebdcded2da8,
            $GLOBALS["__65da1b1ec" . "2d6653e8a0a" . "b7848e53621" . "5"]["_7e84df6509b512ec6d3f619df" . "00b393a"] => $_f4eafa5f493306ffdb51a688b21dd507,
            $GLOBALS["__65da1b1ec2d6653e8" . "a0ab7848e536215"]["_9a8a4d866593d6457472ae60c" . "5e4f771"] => $_f4eafa5f493306ffdb51a688b21dd507,
            
            
            $GLOBALS["__65da1b1ec2" . "d6653e8a0ab7" . "848e536215"]["_9785edd5ebc204f415762081467d2ef" . "5"] => $this->dt_draw,
        );
    }
    
    
    
    
    
    
    
    
    public function Download(SecurityContext $context)
    {
        $_a0006f2e6058ce959e86bebdcded2da8 = $this->source->Data($context, $this->params, $this->filters);
        $_a0006f2e6058ce959e86bebdcded2da8 = $this->ConfigureRows($context, $_a0006f2e6058ce959e86bebdcded2da8, true);
        $_3e258c4e6163007d8094c39647602e7a = array();
        foreach ($this->source->Columns($context, $this->params) as $_16e904583014a98ae3677f33f097518d) {
            $_3e258c4e6163007d8094c39647602e7a[] = $_16e904583014a98ae3677f33f097518d->GetName();
        }
        $data = array();
        foreach ($_a0006f2e6058ce959e86bebdcded2da8 as $_b8cfc2e06d9d1fec1893ea4a054002bf) {
            $data[] = $GLOBALS["__65da1b1e" . "c2d6653e8a" . "0ab7848e53" . "6215"]["_ebff9d37a7" . "bb577c57bee" . "4dd9f0e5fd7"]($_b8cfc2e06d9d1fec1893ea4a054002bf);
        }
        $this->exporter->SetHeaders($_3e258c4e6163007d8094c39647602e7a);
        $this->exporter->ImportFromArray($data);
        return $this->exporter->Export($GLOBALS["__65da1b1ec2d6" . "653e8a0ab7848e" . "536215"]["_b7645596ad3b10cf617a8a1b" . "58014d4b"]);
    }
    
    
    
    
    
    
    
    
    
    
    protected function ConfigureRows(SecurityContext $context, $_a0006f2e6058ce959e86bebdcded2da8, $_34a970f5e5756ae52468c45ad07de116 = false)
    {
        $_e8180e518b009dc0ea8c578fe193c4ae = array();
        $_a42c86642011ef739b88ee80672c387d = $this->source->Columns($context, $this->params);
        foreach ($_a0006f2e6058ce959e86bebdcded2da8 as $_b8cfc2e06d9d1fec1893ea4a054002bf) {
            $_b6e48cd3108f04ee53f45d7a66e14551 = array();
            foreach ($_b8cfc2e06d9d1fec1893ea4a054002bf as $_02ad4799244951c2d809ee37be9e79fd => $_16e904583014a98ae3677f33f097518d) {
                $_24ca62b4d01cc6d515dfd0bea4c9d59a = $_16e904583014a98ae3677f33f097518d;
                if ($_a42c86642011ef739b88ee80672c387d[$_02ad4799244951c2d809ee37be9e79fd]->GetDecorator()) {
                    if ($_34a970f5e5756ae52468c45ad07de116) {
                        $_24ca62b4d01cc6d515dfd0bea4c9d59a = $_a42c86642011ef739b88ee80672c387d[$_02ad4799244951c2d809ee37be9e79fd]->GetDecorator()->Basic($_16e904583014a98ae3677f33f097518d);
                    } else {
                        $_24ca62b4d01cc6d515dfd0bea4c9d59a = $_a42c86642011ef739b88ee80672c387d[$_02ad4799244951c2d809ee37be9e79fd]->GetDecorator()->Decorate($_16e904583014a98ae3677f33f097518d);
                    }
                }
                $_b6e48cd3108f04ee53f45d7a66e14551[$_02ad4799244951c2d809ee37be9e79fd] = $_24ca62b4d01cc6d515dfd0bea4c9d59a;
            }
            $_e8180e518b009dc0ea8c578fe193c4ae[] = $_b6e48cd3108f04ee53f45d7a66e14551;
        }
        return $_e8180e518b009dc0ea8c578fe193c4ae;
    }
    
    
    
    
    
    
    public function SetDtDraw($_9785edd5ebc204f415762081467d2ef5)
    {
        $this->dt_draw = $_9785edd5ebc204f415762081467d2ef5;
    }
}
